@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "buffer-manage" "1.1"
+(define-package "buffer-manage" "20241019.1748"
   "Manage buffers."
   '((emacs          "26.1")
     (choice-program "0.13")
     (dash           "2.17.0"))
   :url "https://github.com/plandes/buffer-manage"
-  :commit "819bbfd9ae2f028361f484bc3b60d751623a2df5"
-  :revdesc "v1.1-0-g819bbfd9ae2f"
+  :commit "3d338b1e64f256ccb70adf81de4c04bcda7eb8d8"
+  :revdesc "3d338b1e64f2"
   :keywords '("internal" "maint"))
