@@ -2,8 +2,8 @@
 
 ;; Copyright (C) 2015 - 2021 Paul Landes
 
-;; Package-Version: 1.1
-;; Package-Revision: v1.1-0-g819bbfd9ae2f
+;; Package-Version: 20241019.1748
+;; Package-Revision: 3d338b1e64f2
 ;; Author: Paul Landes
 ;; Maintainer: Paul Landes
 ;; Keywords: internal maint
@@ -57,7 +57,7 @@
 (defvar buffer-entry-instance)
 
 (defgroup buffer-manage nil
-  "Buffer management and tracking"
+  "Buffer management and tracking."
   :group 'buffer-manage
   :prefix "buffer-manage-")
 
